# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner

class TestPivot200ResponseInner(unittest.TestCase):
    """Pivot200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Pivot200ResponseInner:
        """Test Pivot200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Pivot200ResponseInner`
        """
        model = Pivot200ResponseInner()
        if include_optional:
            return Pivot200ResponseInner(
                p = 1.337,
                r1 = 1.337,
                s1 = 1.337,
                r2 = 1.337,
                s2 = 1.337,
                r3 = 1.337,
                s3 = 1.337
            )
        else:
            return Pivot200ResponseInner(
        )
        """

    def testPivot200ResponseInner(self):
        """Test Pivot200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
