# coding: utf-8

# flake8: noqa
"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from tickcatcher.models.adx200_response_inner import Adx200ResponseInner
from tickcatcher.models.bbands200_response_inner import Bbands200ResponseInner
from tickcatcher.models.bbands_request import BbandsRequest
from tickcatcher.models.bbands_request_params import BbandsRequestParams
from tickcatcher.models.calendar_event import CalendarEvent
from tickcatcher.models.candle import Candle
from tickcatcher.models.ema_request import EmaRequest
from tickcatcher.models.ema_request_params import EmaRequestParams
from tickcatcher.models.heikenashi_request import HeikenashiRequest
from tickcatcher.models.ichimoku200_response_inner import Ichimoku200ResponseInner
from tickcatcher.models.ichimoku_request import IchimokuRequest
from tickcatcher.models.ichimoku_request_params import IchimokuRequestParams
from tickcatcher.models.info import Info
from tickcatcher.models.keltner_request import KeltnerRequest
from tickcatcher.models.keltner_request_params import KeltnerRequestParams
from tickcatcher.models.macd200_response_inner import Macd200ResponseInner
from tickcatcher.models.macd_request import MacdRequest
from tickcatcher.models.macd_request_params import MacdRequestParams
from tickcatcher.models.metadata import Metadata
from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner
from tickcatcher.models.psar_request import PsarRequest
from tickcatcher.models.psar_request_params import PsarRequestParams
from tickcatcher.models.search_result import SearchResult
from tickcatcher.models.sma_request import SmaRequest
from tickcatcher.models.sma_request_params import SmaRequestParams
from tickcatcher.models.stoch200_response_inner import Stoch200ResponseInner
from tickcatcher.models.stoch_request import StochRequest
from tickcatcher.models.stoch_request_params import StochRequestParams
from tickcatcher.models.supertrend200_response_inner import Supertrend200ResponseInner
from tickcatcher.models.supertrend_request import SupertrendRequest
from tickcatcher.models.supertrend_request_params import SupertrendRequestParams

