# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.ultra_indicators_api import UltraIndicatorsApi


class TestUltraIndicatorsApi(unittest.TestCase):
    """UltraIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UltraIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_adx(self) -> None:
        """Test case for adx

        Calculate Average Directional Index (ADX)
        """
        pass

    def test_atr(self) -> None:
        """Test case for atr

        Calculate Average True Range (ATR)
        """
        pass

    def test_cci(self) -> None:
        """Test case for cci

        Calculate Commodity Channel Index (CCI)
        """
        pass

    def test_psar(self) -> None:
        """Test case for psar

        Calculate Parabolic SAR
        """
        pass


if __name__ == '__main__':
    unittest.main()
