# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.basic_indicators_api import BasicIndicatorsApi


class TestBasicIndicatorsApi(unittest.TestCase):
    """BasicIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BasicIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_ema(self) -> None:
        """Test case for ema

        Calculate Exponential Moving Average (EMA)
        """
        pass

    def test_rsi(self) -> None:
        """Test case for rsi

        Calculate Relative Strength Index (RSI)
        """
        pass

    def test_sma(self) -> None:
        """Test case for sma

        Calculate Simple Moving Average (SMA)
        """
        pass


if __name__ == '__main__':
    unittest.main()
