# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.pro_indicators_api import ProIndicatorsApi


class TestProIndicatorsApi(unittest.TestCase):
    """ProIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_bbands(self) -> None:
        """Test case for bbands

        Calculate Bollinger Bands
        """
        pass

    def test_macd(self) -> None:
        """Test case for macd

        Calculate MACD
        """
        pass

    def test_stoch(self) -> None:
        """Test case for stoch

        Calculate Stochastic Oscillator
        """
        pass

    def test_volumema(self) -> None:
        """Test case for volumema

        Calculate Volume MA
        """
        pass


if __name__ == '__main__':
    unittest.main()
