# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.mega_indicators_api import MegaIndicatorsApi


class TestMegaIndicatorsApi(unittest.TestCase):
    """MegaIndicatorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MegaIndicatorsApi()

    def tearDown(self) -> None:
        pass

    def test_heikenashi(self) -> None:
        """Test case for heikenashi

        Calculate Heiken Ashi
        """
        pass

    def test_ichimoku(self) -> None:
        """Test case for ichimoku

        Calculate Ichimoku Cloud
        """
        pass

    def test_supertrend(self) -> None:
        """Test case for supertrend

        Calculate SuperTrend
        """
        pass

    def test_williamsr(self) -> None:
        """Test case for williamsr

        Calculate Williams %R
        """
        pass


if __name__ == '__main__':
    unittest.main()
