# coding: utf-8

# flake8: noqa

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.3"

# Define package exports
__all__ = [
    "BasicIndicatorsApi",
    "CalendarApi",
    "CandlesApi",
    "EnterpriseIndicatorsApi",
    "GeneralApi",
    "MegaIndicatorsApi",
    "ProIndicatorsApi",
    "UltraIndicatorsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Adx200ResponseInner",
    "Bbands200ResponseInner",
    "BbandsRequest",
    "BbandsRequestParams",
    "CalendarEvent",
    "Candle",
    "EmaRequest",
    "EmaRequestParams",
    "HeikenashiRequest",
    "Ichimoku200ResponseInner",
    "IchimokuRequest",
    "IchimokuRequestParams",
    "Info",
    "KeltnerRequest",
    "KeltnerRequestParams",
    "Macd200ResponseInner",
    "MacdRequest",
    "MacdRequestParams",
    "Metadata",
    "Pivot200ResponseInner",
    "PsarRequest",
    "PsarRequestParams",
    "SearchResult",
    "SmaRequest",
    "SmaRequestParams",
    "Stoch200ResponseInner",
    "StochRequest",
    "StochRequestParams",
    "Supertrend200ResponseInner",
    "SupertrendRequest",
    "SupertrendRequestParams",
]

# import apis into sdk package
from tickcatcher.api.basic_indicators_api import BasicIndicatorsApi as BasicIndicatorsApi
from tickcatcher.api.calendar_api import CalendarApi as CalendarApi
from tickcatcher.api.candles_api import CandlesApi as CandlesApi
from tickcatcher.api.enterprise_indicators_api import EnterpriseIndicatorsApi as EnterpriseIndicatorsApi
from tickcatcher.api.general_api import GeneralApi as GeneralApi
from tickcatcher.api.mega_indicators_api import MegaIndicatorsApi as MegaIndicatorsApi
from tickcatcher.api.pro_indicators_api import ProIndicatorsApi as ProIndicatorsApi
from tickcatcher.api.ultra_indicators_api import UltraIndicatorsApi as UltraIndicatorsApi

# import ApiClient
from tickcatcher.api_response import ApiResponse as ApiResponse
from tickcatcher.api_client import ApiClient as ApiClient
from tickcatcher.configuration import Configuration as Configuration
from tickcatcher.exceptions import OpenApiException as OpenApiException
from tickcatcher.exceptions import ApiTypeError as ApiTypeError
from tickcatcher.exceptions import ApiValueError as ApiValueError
from tickcatcher.exceptions import ApiKeyError as ApiKeyError
from tickcatcher.exceptions import ApiAttributeError as ApiAttributeError
from tickcatcher.exceptions import ApiException as ApiException

# import models into sdk package
from tickcatcher.models.adx200_response_inner import Adx200ResponseInner as Adx200ResponseInner
from tickcatcher.models.bbands200_response_inner import Bbands200ResponseInner as Bbands200ResponseInner
from tickcatcher.models.bbands_request import BbandsRequest as BbandsRequest
from tickcatcher.models.bbands_request_params import BbandsRequestParams as BbandsRequestParams
from tickcatcher.models.calendar_event import CalendarEvent as CalendarEvent
from tickcatcher.models.candle import Candle as Candle
from tickcatcher.models.ema_request import EmaRequest as EmaRequest
from tickcatcher.models.ema_request_params import EmaRequestParams as EmaRequestParams
from tickcatcher.models.heikenashi_request import HeikenashiRequest as HeikenashiRequest
from tickcatcher.models.ichimoku200_response_inner import Ichimoku200ResponseInner as Ichimoku200ResponseInner
from tickcatcher.models.ichimoku_request import IchimokuRequest as IchimokuRequest
from tickcatcher.models.ichimoku_request_params import IchimokuRequestParams as IchimokuRequestParams
from tickcatcher.models.info import Info as Info
from tickcatcher.models.keltner_request import KeltnerRequest as KeltnerRequest
from tickcatcher.models.keltner_request_params import KeltnerRequestParams as KeltnerRequestParams
from tickcatcher.models.macd200_response_inner import Macd200ResponseInner as Macd200ResponseInner
from tickcatcher.models.macd_request import MacdRequest as MacdRequest
from tickcatcher.models.macd_request_params import MacdRequestParams as MacdRequestParams
from tickcatcher.models.metadata import Metadata as Metadata
from tickcatcher.models.pivot200_response_inner import Pivot200ResponseInner as Pivot200ResponseInner
from tickcatcher.models.psar_request import PsarRequest as PsarRequest
from tickcatcher.models.psar_request_params import PsarRequestParams as PsarRequestParams
from tickcatcher.models.search_result import SearchResult as SearchResult
from tickcatcher.models.sma_request import SmaRequest as SmaRequest
from tickcatcher.models.sma_request_params import SmaRequestParams as SmaRequestParams
from tickcatcher.models.stoch200_response_inner import Stoch200ResponseInner as Stoch200ResponseInner
from tickcatcher.models.stoch_request import StochRequest as StochRequest
from tickcatcher.models.stoch_request_params import StochRequestParams as StochRequestParams
from tickcatcher.models.supertrend200_response_inner import Supertrend200ResponseInner as Supertrend200ResponseInner
from tickcatcher.models.supertrend_request import SupertrendRequest as SupertrendRequest
from tickcatcher.models.supertrend_request_params import SupertrendRequestParams as SupertrendRequestParams

