# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.models.sma_request_params import SmaRequestParams

class TestSmaRequestParams(unittest.TestCase):
    """SmaRequestParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SmaRequestParams:
        """Test SmaRequestParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SmaRequestParams`
        """
        model = SmaRequestParams()
        if include_optional:
            return SmaRequestParams(
                period = 56
            )
        else:
            return SmaRequestParams(
        )
        """

    def testSmaRequestParams(self):
        """Test SmaRequestParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
