# coding: utf-8

"""
    Tickcatcher API

    The Tickcatcher API provides access to cryptocurrency market data including candlesticks, symbols, and indicators. All requests require authentication using your RapidAPI key. 

    The version of the OpenAPI document: 1.1.3
    Contact: yagiz@iskirik.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tickcatcher.api.candles_api import CandlesApi


class TestCandlesApi(unittest.TestCase):
    """CandlesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CandlesApi()

    def tearDown(self) -> None:
        pass

    def test_basic_candles(self) -> None:
        """Test case for basic_candles

        Get candlestick data
        """
        pass

    def test_enterprise_candles(self) -> None:
        """Test case for enterprise_candles

        Get candlestick data
        """
        pass

    def test_mega_candles(self) -> None:
        """Test case for mega_candles

        Get candlestick data
        """
        pass

    def test_pro_candles(self) -> None:
        """Test case for pro_candles

        Get candlestick data
        """
        pass

    def test_ultra_candles(self) -> None:
        """Test case for ultra_candles

        Get candlestick data
        """
        pass


if __name__ == '__main__':
    unittest.main()
